@@ -11,7 +11,7 @@ use File::Find;
 use File::Spec;
 use Data::Dumper;
 
-our $VERSION = '0.304';
+our $VERSION = '0.307';
 
 sub import {
 	my $class = shift;
@@ -112,6 +112,7 @@ sub install {
 
 sub save_config {
 	use Data::Dumper;
+	local $Data::Dumper::Terse = 0;
 	use IO::File;
 
 	my ($self, $filename) = @_;
@@ -120,20 +121,17 @@ sub save_config {
 		or croak "can't open '$filename' for writing: $!\n";
 
 	print $file "package $self->{name}\::Install::Files;\n\n";
-	# for modern stuff
 	print $file "".Data::Dumper->Dump([{
 		inc => join (" ", @{ $self->{inc} }),
 		libs => $self->{libs},
 		typemaps => [ map { basename $_ } @{ $self->{typemaps} } ],
 		deps => [keys %{ $self->{deps} }],
 	}], ['self']);
-	# for ancient stuff
-	print $file "\n\n# this is for backwards compatiblity\n";
-	print $file "\@deps = \@{ \$self->{deps} };\n";
+	print $file "\n\n\@deps = \@{ \$self->{deps} };\n";
 	print $file "\@typemaps = \@{ \$self->{typemaps} };\n";
 	print $file "\$libs = \$self->{libs};\n";
 	print $file "\$inc = \$self->{inc};\n";
-	# this is riduculous, but old versions of ExtUtils::Depends take
+	# this is ridiculous, but old versions of ExtUtils::Depends take
 	# first $loadedmodule::CORE and then $INC{$file} --- the fallback
 	# includes the Filename.pm, which is not useful.  so we must add
 	# this crappy code.  we don't worry about portable pathnames,
@@ -306,6 +304,9 @@ sub build_dll_lib {
 		'$(INST_ARCHAUTODIR)/$(BASEEXT)$(LIB_EXT)';
 }
 
+# Search for extra library files to link against on Windows (either native
+# Windows library # files, or Cygwin library files)
+# NOTE: not meant to be called publicly, so no POD documentation
 sub find_extra_libs {
 	my $self = shift;
 
@@ -399,7 +400,7 @@ that a perl extension is treated like a shared library that provides
 also a C and an XS interface besides the perl one.
 
 This works as long as the base extension is loaded with the RTLD_GLOBAL
-flag (usually done with a 
+flag (usually done with a
 
 	sub dl_load_flags {0x01}
 
@@ -411,6 +412,9 @@ may be retrieved later.  The object can also reformat this information
 into the data structures required by ExtUtils::MakeMaker's WriteMakefile
 function.
 
+For information on how to make your module fit into this scheme, see
+L</"hashref = ExtUtils::Depends::load (name)">.
+
 When creating a new Depends object, you give it a name, which is the name
 of the module you are building.   You can also specify the names of modules
 on which this module depends.  These dependencies will be loaded
@@ -543,6 +547,14 @@ loading files created by old versions of ExtUtils::Depends.
 
 =back
 
+If you want to make module I<name> support this, you must provide
+a module I<name>::Install::Files, which on loading will provide the
+following package variables: C<@typemaps>, C<$inc>, C<$libs>, C<$deps>,
+with the same contents as above (not coincidentally). The C<load>
+function will supply the C<instpath>. An easy way to achieve this is
+to use the method L</"$depends-E<gt>save_config ($filename)">, but your
+package may have different facilities already.
+
 =item $depends->load_deps
 
 Load I<$depends> dependencies, by calling C<load> on each dependency module.
@@ -551,8 +563,9 @@ C<get_deps> after calling C<add_deps> manually.
 
 =back
 
+=head1 SUPPORT
 
-=head1 BUGS
+=head2 Bugs/Feature Requests
 
 Version 0.2 discards some of the more esoteric features provided by the
 older versions.  As they were completely undocumented, and this module
@@ -560,6 +573,39 @@ has yet to reach 1.0, this may not exactly be a bug.
 
 This module is tightly coupled to the ExtUtils::MakeMaker architecture.
 
+You can submit new bugs/feature requests by using one of two bug trackers
+(below).
+
+=over
+
+=item CPAN Request Tracker
+
+You can submit bugs/feature requests via the web by going to
+L<https://rt.cpan.org/Public/Bug/Report.html?Queue=ExtUtils-Depends> (requires
+PAUSE ID or Bitcard), or by sending an e-mail to
+L<bug-ExtUtils-Depends at rt.cpan.org>.
+
+=item Gnome.org Bugzilla
+
+Report bugs/feature requests to the 'gnome-perl' product (requires login)
+L<http://bugzilla.gnome.org/enter_bug.cgi?product=gnome-perl>
+
+=back
+
+Patches that implement new features with test cases, and/or test cases that
+exercise existing bugs are always welcome.
+
+The Gtk-Perl mailing list is at L<gtk-perl-list at gnome dot org>.
+
+=head2 Source Code
+
+The source code to L<ExtUtils::Depends> is available at the Gnome.org Git repo
+(L<https://git.gnome.org/browse/perl-ExtUtils-Depends/>).  Create your own
+copy of the Git repo with:
+
+  git clone git://git.gnome.org/perl-ExtUtils-Depends (Git protocol)
+  git clone https://git.gnome.org/browse/perl-ExtUtils-Depends/ (HTTPS)
+
 =head1 SEE ALSO
 
 ExtUtils::MakeMaker.
@@ -572,7 +618,7 @@ version 0.2, borrowing liberally from Paolo's code.
 
 =head1 MAINTAINER
 
-The Gtk2 project, http://gtk2-perl.sf.net/
+The Gtk2 project, L<http://gtk2-perl.sf.net>/L<gtk-perl-list at gnome dot org>.
 
 =head1 LICENSE
 
